==> haskell-lifted-async-0.9.3.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.3.2
id: lifted-async-0.9.3.2-CCb7vEhkVAc1tcfbbiyqSA
key: lifted-async-0.9.3.2-CCb7vEhkVAc1tcfbbiyqSA
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: 1463ef6d96a1be5ff713964c2ad03828
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lifted-async-0.9.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/lifted-async-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/lifted-async-0.9.3.2
hs-libraries: HSlifted-async-0.9.3.2-CCb7vEhkVAc1tcfbbiyqSA
depends:
    base-4.10.1.0 async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
    lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
    constraints-0.9.1-G6wiOdb95ZhE9bigb7mWFX
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=2f2bfb87d27ef4e5ac013c6e1a680f92
             lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8=e82f2409efab3091fa542aee1ccbd459
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=e96596ff8dc8b61f0eaf7d04e05900dc
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=e28d37063c38c75b3bf039284c73d58f
             constraints-0.9.1-G6wiOdb95ZhE9bigb7mWFX=9b74dc205ecfadd11d5d1f88061697bb
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.9.3.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.3.2
id: lifted-async-0.9.3.2-9hIUFI5PEEvL9CvuMybmoI
key: lifted-async-0.9.3.2-9hIUFI5PEEvL9CvuMybmoI
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: 2b5a9381e8ece931e81671250036dc79
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lifted-async-0.9.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/lifted-async-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/lifted-async-0.9.3.2
hs-libraries: HSlifted-async-0.9.3.2-9hIUFI5PEEvL9CvuMybmoI
depends:
    base-4.10.1.0 async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
    lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
    constraints-0.9.1-KhLgLA3PTXIF1GDmZNV1pb
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=2f2bfb87d27ef4e5ac013c6e1a680f92
             lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8=e82f2409efab3091fa542aee1ccbd459
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=e96596ff8dc8b61f0eaf7d04e05900dc
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=e28d37063c38c75b3bf039284c73d58f
             constraints-0.9.1-KhLgLA3PTXIF1GDmZNV1pb=509af8ece382f324f71a4c5e2728a468
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
